==> acm-sdk-1.0.8-sources.jar: com/alibaba/acm/shaded/com/aliyuncs/kms/transform/v20160120/DescribeKeyResponseUnmarshaller.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package com.alibaba.acm.shaded.com.aliyuncs.kms.transform.v20160120;

import com.alibaba.acm.shaded.com.aliyuncs.kms.model.v20160120.DescribeKeyResponse;
import com.alibaba.acm.shaded.com.aliyuncs.kms.model.v20160120.DescribeKeyResponse.KeyMetadata;
import com.alibaba.acm.shaded.com.aliyuncs.transform.UnmarshallerContext;


public class DescribeKeyResponseUnmarshaller {

	public static DescribeKeyResponse unmarshall(DescribeKeyResponse describeKeyResponse, UnmarshallerContext context) {
		
		describeKeyResponse.setRequestId(context.stringValue("DescribeKeyResponse.RequestId"));

		KeyMetadata keyMetadata = new KeyMetadata();
		keyMetadata.setCreationDate(context.stringValue("DescribeKeyResponse.KeyMetadata.CreationDate"));
		keyMetadata.setDescription(context.stringValue("DescribeKeyResponse.KeyMetadata.Description"));
		keyMetadata.setKeyId(context.stringValue("DescribeKeyResponse.KeyMetadata.KeyId"));
		keyMetadata.setKeyState(context.stringValue("DescribeKeyResponse.KeyMetadata.KeyState"));
		keyMetadata.setKeyUsage(context.stringValue("DescribeKeyResponse.KeyMetadata.KeyUsage"));
		keyMetadata.setDeleteDate(context.stringValue("DescribeKeyResponse.KeyMetadata.DeleteDate"));
		keyMetadata.setCreator(context.stringValue("DescribeKeyResponse.KeyMetadata.Creator"));
		keyMetadata.setArn(context.stringValue("DescribeKeyResponse.KeyMetadata.Arn"));
		describeKeyResponse.setKeyMetadata(keyMetadata);
	 
	 	return describeKeyResponse;
	}
}

==> acm-sdk-1.0.9-sources.jar: com/alibaba/acm/shaded/com/aliyuncs/kms/transform/v20160120/DescribeKeyResponseUnmarshaller.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.alibaba.acm.shaded.com.aliyuncs.kms.transform.v20160120;

import com.alibaba.acm.shaded.com.aliyuncs.kms.model.v20160120.DescribeKeyResponse;
import com.alibaba.acm.shaded.com.aliyuncs.kms.model.v20160120.DescribeKeyResponse.KeyMetadata;
import com.alibaba.acm.shaded.com.aliyuncs.transform.UnmarshallerContext;


public class DescribeKeyResponseUnmarshaller {

	public static DescribeKeyResponse unmarshall(DescribeKeyResponse describeKeyResponse, UnmarshallerContext context) {
		
		describeKeyResponse.setRequestId(context.stringValue("DescribeKeyResponse.RequestId"));

		KeyMetadata keyMetadata = new KeyMetadata();
		keyMetadata.setCreationDate(context.stringValue("DescribeKeyResponse.KeyMetadata.CreationDate"));
		keyMetadata.setDescription(context.stringValue("DescribeKeyResponse.KeyMetadata.Description"));
		keyMetadata.setKeyId(context.stringValue("DescribeKeyResponse.KeyMetadata.KeyId"));
		keyMetadata.setKeyState(context.stringValue("DescribeKeyResponse.KeyMetadata.KeyState"));
		keyMetadata.setKeyUsage(context.stringValue("DescribeKeyResponse.KeyMetadata.KeyUsage"));
		keyMetadata.setDeleteDate(context.stringValue("DescribeKeyResponse.KeyMetadata.DeleteDate"));
		keyMetadata.setCreator(context.stringValue("DescribeKeyResponse.KeyMetadata.Creator"));
		keyMetadata.setArn(context.stringValue("DescribeKeyResponse.KeyMetadata.Arn"));
		keyMetadata.setOrigin(context.stringValue("DescribeKeyResponse.KeyMetadata.Origin"));
		keyMetadata.setMaterialExpireTime(context.stringValue("DescribeKeyResponse.KeyMetadata.MaterialExpireTime"));
		describeKeyResponse.setKeyMetadata(keyMetadata);
	 
	 	return describeKeyResponse;
	}
}
